@@ -63,7 +63,8 @@ class CDx_Data():
                  mut_df: pd.DataFrame = None,
                  cli_df: pd.DataFrame = None,
                  cnv_df: pd.DataFrame = None,
-                 sv_df: pd.DataFrame = None):
+                 sv_df: pd.DataFrame = None,
+                 json_str: str = None):
         """Constructor method with DataFrames
 
         Args:
@@ -73,7 +74,7 @@ class CDx_Data():
             sv_df (pd.DataFrame, optional): SV info. Defaults to None.
         """
 
-        self.json_str = None
+        self.json_str = json_str
 
         self.mut = mut_df
         self.cnv = cnv_df
@@ -543,10 +544,11 @@ class CDx_Data():
         Returns:
             CDx_Data: CDx_Data object
         """
-        if self.mut is None:
-            raise VariantUndefinedError(f'mut variant undefied')
+        if self.mut is None or len(self.mut) == 0:
+            mut = None
+        else:
+            mut = self._selector(self.mut, kwargs)
 
-        mut = self._selector(self.mut, kwargs)
         return CDx_Data(cli_df=self.cli,
                         mut_df=mut,
                         cnv_df=self.cnv,
@@ -561,10 +563,10 @@ class CDx_Data():
         Returns:
             CDx_Data: CDx_Data object.
         """
-        if self.cnv is None:
-            raise VariantUndefinedError(f'cnv variant undefied')
-
-        cnv = self._selector(self.cnv, kwargs)
+        if self.cnv is None or len(self.cnv) == 0:
+            cnv = None
+        else:
+            cnv = self._selector(self.cnv, kwargs)
         return CDx_Data(cli_df=self.cli,
                         mut_df=self.mut,
                         cnv_df=cnv,
@@ -579,10 +581,10 @@ class CDx_Data():
         Returns:
             CDx_Data: CDx_Data object.
         """
-        if self.sv is None:
-            raise VariantUndefinedError(f'sv variant undefied')
-
-        sv = self._selector(self.sv, kwargs)
+        if self.sv is None or len(self.sv) == 0:
+            sv = None
+        else:
+            sv = self._selector(self.sv, kwargs)
         return CDx_Data(cli_df=self.cli,
                         mut_df=self.mut,
                         cnv_df=self.cnv,
